@@ -11,7 +11,7 @@ log = logging.getLogger(__name__)
 
 __author__ = 'Erik-Jan van Baaren'
 __all__ = ['ESClient']
-__version__ = (0, 2, 0)
+__version__ = (0, 2, 1)
 
 
 def get_version():
@@ -59,21 +59,16 @@ class ESClient:
             path = '/' + path
         return path
 
-    def check_result(self, list, key, value):
+    def check_result(self, results, key, value):
         """Check if key is an element of list, and check if that element
         is equal (==) to value.
         
         Returns True if the key exists and is equal to given value, false
         otherwise.
         """
-        try:
-            if list[key] == value:
-                return True
-            else:
-                return False
-        except:
-            return False
-
+        if key in results:
+            return results[key] == value
+        
     def send_request(self, method, path, body=None, query_string_args={}):
         """Make a raw HTTP request to ElasticSearch.
 
@@ -378,5 +373,27 @@ class ESClient:
         resp = json.loads(self.last_response.text)
         return self.check_result(resp, 'ok', True)
 
+    def status(self, indexes=['_all']):
+        """Retrieve the status of one or more indices.
+        
+        """
+        path = self._make_path([','.join(indexes), '_status'])
+        self.send_request('GET', path)
+        return json.loads(self.last_response.text)
+
+    def flush(self, indexes=['_all'], refresh=False):
+        """Flush one or more indexes.
+        
+        Flush frees memory from the index by flushing data to the index
+        storage and clearing the internal transaction log.
+        """
+        path = self._make_path([','.join(indexes), '_flush'])
+        args = {}
+        if refresh:
+            args['refresh'] = "true"
+        self.send_request('POST', path, query_string_args=args)
+        resp = json.loads(self.last_response.text)
+        return self.check_result(resp, 'ok', True)
+
 if __name__ == '__main__':
     print "This is a library, it is not intended to be started by itself."
